@@ -13,7 +13,7 @@ use vars qw($VERSION);
 use Image::ExifTool;    # only for FinishTiffDump()
 use Image::ExifTool::HTML qw(EscapeHTML);
 
-$VERSION = '1.37';
+$VERSION = '1.39';
 
 sub DumpTable($$$;$$$$$$);
 sub Open($$$;@);
@@ -97,7 +97,8 @@ var YTOP = 20;  // y offset when above cursor
 var safari1 = navigator.userAgent.indexOf("Safari/312.6") >= 0;
 var ie6 = navigator.userAgent.toLowerCase().indexOf('msie 6') >= 0;
 var mspan = new Array;
-var hlist, tt, tb;
+var clicked = 0;
+var hlist, tt, tb, firstOutEvt, lastInEvt;
 
 function GetElementsByClass(classname, tagname) {
   var found = new Array();
@@ -115,6 +116,20 @@ function GetElementsByClass(classname, tagname) {
   return found;
 }
 
+// click mouse
+function doClick(e)
+{
+  if (!clicked) {
+    firstOutEvt = lastInEvt = undefined;
+    high(e, 2);
+    if (hlist) clicked = 1;
+  } else {
+    clicked = 0;
+    if (firstOutEvt) high(firstOutEvt, 0);
+    if (lastInEvt) high(lastInEvt, 1);
+  }
+}
+
 // move tooltip
 function move(e)
 {
@@ -162,6 +177,12 @@ function move(e)
 
 // highlight/unhighlight text
 function high(e,on) {
+  if (on) {
+    lastInEvt = e;
+  } else {
+    if (!firstOutEvt) firstOutEvt = e;
+  }
+  if (clicked) return;
   var targ;
   if (e.target) targ = e.target;
   else if (e.srcElement) targ = e.srcElement;
@@ -209,7 +230,7 @@ function high(e,on) {
       }
       for (var i=0; i<hlist.length; ++i) {
         for (var j=0; j<hlist[i].length; ++j) {
-          hlist[i][j].style.background = '#ffcc99';
+          hlist[i][j].style.background = on == 2 ? '#ffbbbb' : '#ffcc99';
         }
       }
     }
@@ -226,7 +247,7 @@ Enable JavaScript for active highlighting and information tool tips!
 <table class=dump cellspacing=0 cellpadding=2>
 <tr><td valign='top'><pre>];
 
-my $preMouse = q(<pre onmouseover="high(event,1)" onmouseout="high(event,0)" onmousemove="move(event)">);
+my $preMouse = q(<pre onmouseover="high(event,1)" onmouseout="high(event,0)" onmousemove="move(event)" onmousedown="doClick(event)">);
 
 #------------------------------------------------------------------------------
 # New - create new HtmlDump object
@@ -896,7 +917,7 @@ page.
 
 =head1 AUTHOR
 
-Copyright 2003-2020, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2021, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
